@@ -1,4 +1,4 @@
-plot.cec <- function(x, col, cex = 0.5, pch = 19, cex.centers = 1, pch.centers = 8, ellipses.lwd = 4, ellipses = TRUE, model = T, xlab, ylab, ...)
+plot.cec <- function(x, col, cex = 0.5, pch = 19, cex.centers = 1, pch.centers = 8, ellipses.lwd = 4, ellipses = TRUE, model = TRUE, xlab, ylab, ...)
 {
     if (ncol (x $ data) != 2 )
         stop("plotting available only for 2-dimensional data")
@@ -45,4 +45,4 @@ plot.cec <- function(x, col, cex = 0.5, pch = 19, cex.centers = 1, pch.centers =
                     finally = {})     
             }
     }  
-}
\ No newline at end of file
+}
